==> dart_chainsql_api-1.0.5.tar.gz: lib/src/core/runtime/Value.dart <==
//import 'dart:js';
import 'dart:typed_data';

enum Value {
  UNKNOWN,
  STRING,
  JSON_OBJECT,
  JSON_ARRAY,
  LIST,
  MAP,
  NUMBER,
  BYTE,
  DOUBLE,
  FLOAT,
  INTEGER,
  LONG,
  BYTE_ARRAY,
  SHORT,
  BOOLEAN
}

class ValueTool {
  static Value typeOf(Object object) {
//    var ret = object.runtimeType;
//
//    print("$ret");

    if (object.runtimeType == String) {
      return Value.STRING;
    } else if (object.runtimeType == int) {
      return Value.INTEGER;
    } else if (object.runtimeType == num) {
      //flutter don't support ffi:Uint8
//      if (object.runtimeType == Uint8) {
//        return Value.BYTE;
//      }

//      else if (object instanceof Double) {
//        return Value.DOUBLE;
//      }
//      else if (object instanceof Float) {
//        return Value.FLOAT;
//      }
//      else if (object instanceof Long) {
//        return Value.LONG;
//      }
//      else if (object instanceof Short) {
//        return Value.SHORT;
//      }
      return Value.NUMBER;
    } else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<dynamic, dynamic>") {
      return Value.MAP;
    }else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<String, dynamic>") {
      return Value.MAP;
    }else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<String, String>") {
      return Value.JSON_OBJECT;
    }
    else if ( object.runtimeType.toString() ==
        "List<Map<String, dynamic>>") {
      return Value.JSON_ARRAY;
    }
    else if (object.runtimeType == Map) {
      return Value.JSON_ARRAY;
    } else if (object.runtimeType == bool) {
      return Value.BOOLEAN;
    } else if (object.runtimeType == List) {
      return Value.LIST;
    } else if (object.runtimeType == Uint8List) {
      return Value.BYTE_ARRAY;
    } else {
      return Value.UNKNOWN;
    }
  }
}

==> dart_chainsql_api-1.0.8.tar.gz: lib/src/core/runtime/Value.dart <==
//import 'dart:js';
import 'dart:typed_data';

enum Value {
  UNKNOWN,
  STRING,
  JSON_OBJECT,
  JSON_ARRAY,
  LIST,
  MAP,
  NUMBER,
  BYTE,
  DOUBLE,
  FLOAT,
  INTEGER,
  LONG,
  BYTE_ARRAY,
  SHORT,
  BOOLEAN
}

class ValueTool {
  static Value typeOf(Object object) {
//    var ret = object.runtimeType;
//
//    print("$ret");

    if (object.runtimeType == String) {
      return Value.STRING;
    } else if (object.runtimeType == int) {
      return Value.INTEGER;
    } else if (object.runtimeType == num) {
      //flutter don't support ffi:Uint8
//      if (object.runtimeType == Uint8) {
//        return Value.BYTE;
//      }

//      else if (object instanceof Double) {
//        return Value.DOUBLE;
//      }
//      else if (object instanceof Float) {
//        return Value.FLOAT;
//      }
//      else if (object instanceof Long) {
//        return Value.LONG;
//      }
//      else if (object instanceof Short) {
//        return Value.SHORT;
//      }
      return Value.NUMBER;
    } else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<dynamic, dynamic>") {
      return Value.MAP;
    }else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<String, dynamic>") {
      return Value.JSON_OBJECT;
    }else if (object.runtimeType.toString() ==
        "_InternalLinkedHashMap<String, String>") {
      return Value.JSON_OBJECT;
    }
    else if ( object.runtimeType.toString() ==
        "List<Map<String, dynamic>>" || object.runtimeType.toString() ==
        "_GrowableList<Map<String, dynamic>>" ) {
      return Value.JSON_ARRAY;
    }
    else if (object.runtimeType == Map) {
      return Value.JSON_ARRAY;
    } else if (object.runtimeType == bool) {
      return Value.BOOLEAN;
    } else if (object.runtimeType == List) {
      return Value.LIST;
    } else if (object.runtimeType == Uint8List) {
      return Value.BYTE_ARRAY;
    } else {
      return Value.UNKNOWN;
    }
  }
}
